@@ -15,7 +15,7 @@ def runfcgi(application, before_daemon=None):
             method              =   'threaded',
             daemonize           =   False,
             workdir             =   '.',
-            pidfile             =   '/var/run/flask.pid',
+            pidfile             =   '',
             maxspare            =    5,
             minspare            =    2,
             maxchildren          =    50,
@@ -35,7 +35,7 @@ def runfcgi(application, before_daemon=None):
         runfastcgi(
             application         =  application,
             protocol            =  protocol,
-            hostname            =  hostname,
+            host                =  hostname,
             port                =  port,
             socket              =  socket,
             method              =  method,
